# NameCoach PHP SDK

The NameCoach PHP SDK provides easy accessibility to [NameCoach API](https://www.name-coach.com/api/private/v2/documentation).

There are also ready-made examples for moving NameCoach API data into various SiS.

The NameCoach platform provides recording and playback services to assist with name pronunciation. Users record their own names by calling via telephone or recording in the browser. Recordings are then made available via embeddable widgets and the NameCoach API.

## Installing

To install this package using composer:

```
composer require namecoach/php-sdk 1.0.*
```

or 

```
  "require": {
    "namecoach/php-sdk": "1.0.*"
  }
```

If you don't want to use Composer, just download the master zip file and load the bootstrap manually:

```
require_once('src/sdk.php');
```

## Quick Start

The fastest way to test your API connection is to run the console example:

```
cd examples
php console_download.php
```

The above example is pre-configured to connect to the Namecoach API endpoint, fetch sample data, and print it to the console.

## Debugging

The SDK includes a `Log` service that can be extended with your own providers by implementing `NameCoach\Logger\Providers\LoggerProvider`. A `ConsoleLogger` provider is supplied, but not used by default.

To enable logging, initialize the logger as follows:

```
Namecoach\Logger\Log::init(new Namecoach\Logger\Providers\ConsoleLogger());
```

## API Methods

### `__construct($name_page_id)`

Initialie the API with a given Name Page ID. NameCoach groups recording information into Name Pages. A single Name Page may contain zero or more name recordings. You can find your Name Page ID by FIXME.

For testing purposes, use Name Page ID `example-237eyc55` from our demo account.

```
$api = new Namecoach\Api("example-237eyc55");
```

### `get_students()`

Query the Name Page ID and return an array of `Namecoach\Student` objects.

```
$students = $api->get_students();

foreach($students as $student)
{
  var_dump($student);
}
```

## Integrating the SDK using SiS Providers

The NameCoach PHP SDK includes providers to integrate with various SiS backends you may be running. The following providers are currently supported:

1. Console
2. Sunguard Eschool

Using an SiS provider instead of writing your own solution, or writing your own SiS backend solution using our provider pattern has several advantages: 

1. The solution is compatible with other NameCoach SDK code and samples which use the provider pattern
2. The solution works seamlessly with the NameCoach SDK data types
3. The solution ensures that all corner cases are covered

### Using an existing SiS provider

If your SiS is already supported by one of the included providers, you may use it. Go to `src/SisProviders` and find the one you are looking for. Inspect the source code for further documentation on its specific use, including any special configuration or constructor logic that may be required, and additional methods it may implement.

All providers must implement a single `write_student()` method. The method takes a `Student` object and is responsible for writing it to the supported SiS backend system.

To use a provider, follow these steps:


When you instantiate our API, you must supply a Name Page ID. NameCoach groups recording information
into Name Pages. A single Name Page may contain zero or more name recordings. You can find your
Name Page ID by FIXME

In this example, we use an demo Name Page ID that is always valid.

```
$api = new Namecoach\Api("example-237eyc55");
```

Make an API call to fetch all students from the NameCoach Name Page specified above.

```
$students = $api->get_students();
```

Here comes the magic. In this example, we use the ConsoleProvider which does nothing more than echo the student ID and
audio URL to the console.

```
$provider = new Namecoach\SisProviders\ConsoleProvider();
```

Now that we have a provider object, we can look through our student object, calling the `write_student()` method.

```
foreach($students as $student)
{
  $provider->write_student($student);
}
```

### Writing your own SiS provider

To write your own provider, you must implement the `SisProviderInterface` interface as shown below.

Your provider must implement a single method, `write_student()`. The method takes a `Student` object and is responsible for writing it to your SiS backend of choice.

```
class MyProvider implements NameCoach\SisProviderInterface
{
  function write_student(Student $student)
  {
    // Do whatever is required to write to your SiS backend
  }
}
```
## Requirements

PHP 5.4 or better is required.

## Contributing

Got something to add? No problem, just fork this repo and send us a pull request.

## License

Please see LICENSE file.
